gbr/js/global
Types
A long integer value, the request ID, that uniquely identifies the entry in the callback list. This is a non-zero value, but you may not make any other assumptions about its value. You can pass this value to window.cancelAnimationFrame() to cancel the refresh callback request.
pub type RequestID
pub type WakeLockSentinal
Values
pub fn add_event_listener(
type_: String,
listener: fn(jsevent.JsEvent(t)) -> Nil,
) -> Nil
pub fn cancel_animation_frame(request_id: RequestID) -> Nil
pub fn clear_interval(id: TimerID) -> Nil
pub fn clear_timeout(timer: TimerID) -> Nil
pub fn decode_uri(a: String) -> String
pub fn decode_uri_component(a: String) -> String
pub fn document(window: Window) -> jsdocument.JsDocument
pub fn dom_content_loaded(
listener: fn(jsevent.JsEvent(t)) -> Nil,
) -> Nil
pub fn encode_uri(a: String) -> String
pub fn get_search() -> Result(String, Nil)
pub fn inner_height(window: Window) -> Int
pub fn inner_width(window: Window) -> Int
pub fn location_of(window: Window) -> Result(String, String)
pub fn match_media(selector: String) -> Bool
pub fn outer_height(window: Window) -> Int
pub fn outer_width(window: Window) -> Int
pub fn queue_microtask(callback: fn() -> Nil) -> Nil
pub fn request_animation_frame(
callback: fn(Float) -> Nil,
) -> RequestID
pub fn request_wake_lock() -> promise.Promise(
Result(WakeLockSentinal, Nil),
)
pub fn screen_left(window: Window) -> Int
pub fn screen_top(window: Window) -> Int
pub fn set_interval(
delay: Int,
callback: fn() -> anything,
) -> TimerID
pub fn set_location(window: Window, url: String) -> Nil
pub fn set_timeout(
delay: Int,
callback: fn() -> anything,
) -> TimerID